function commonSubmitArgs = getCommonSubmitArgs(cluster, numWorkers)
% Get any additional submit arguments for the Slurm sbatch command
% that are common to both independent and communicating jobs.

% Copyright 2016-2022 The MathWorks, Inc.

% wiki:

commonSubmitArgs = '';

% Number of cores/node
ppn = validatedPropValue(cluster, 'ProcsPerNode', 'double');
if ppn>0
    % Don't request more cores/node than workers
    ppn = min(numWorkers*cluster.NumThreads,ppn);
    assert(rem(ppn,cluster.NumThreads)==0, ...
        'ProcsPerNode (%d) must be greater than or equal to and divisible by NumThreads (%d).', ppn, cluster.NumThreads);
    commonSubmitArgs = sprintf('%s --ntasks-per-node=%d',commonSubmitArgs,ppn/cluster.NumThreads);
end
commonSubmitArgs = sprintf('%s --ntasks-per-core=1',commonSubmitArgs);

%% REQUIRED


%% OPTIONAL

% Queue name
qn = validatedPropValue(cluster, 'QueueName', 'char');
if ~isempty(qn)
    commonSubmitArgs = sprintf('%s -p %s', commonSubmitArgs, qn);
end

% GPU
ngpus = validatedPropValue(cluster, 'GpusPerNode', 'double');
if ngpus>0
    gcard = validatedPropValue(cluster, 'GpuCard', 'char');
    commonSubmitArgs = sprintf('%s --gres=gpu:%s:%d', commonSubmitArgs, gcard, ngpus);
    commonSubmitArgs = strrep(commonSubmitArgs,'::',':');
end

% Wall time
wt = validatedPropValue(cluster, 'WallTime', 'char');
if ~isempty(wt)
    commonSubmitArgs = sprintf('%s -t %s', commonSubmitArgs, wt);
end

% Physical memory used by a single core
mu = validatedPropValue(cluster, 'MemUsage', 'char');
if ~isempty(mu)
    commonSubmitArgs = sprintf('%s --mem-per-cpu=%s', commonSubmitArgs, mu);
end

% Reservation
res = validatedPropValue(cluster, 'Reservation', 'char');
if ~isempty(res)
    commonSubmitArgs = sprintf('%s --reservation=%s', commonSubmitArgs, res);
end

% Require exclusive node
ren = validatedPropValue(cluster, 'RequireExclusiveNode', 'bool');
if ren
    commonSubmitArgs = sprintf('%s --exclusive', commonSubmitArgs);
end

% Email notification
ea = validatedPropValue(cluster, 'EmailAddress', 'char');
if ~isempty(ea)
    commonSubmitArgs = sprintf('%s --mail-type=ALL --mail-user=%s', commonSubmitArgs, ea);
end

% Catch-all
asa = validatedPropValue(cluster, 'AdditionalSubmitArgs', 'char');
if ~isempty(asa)
    commonSubmitArgs = sprintf('%s %s', commonSubmitArgs, asa);
end

commonSubmitArgs = strtrim(commonSubmitArgs);

end
